
XEP-0490: Message Displayed Synchronization
===========================================

.. module:: slixmpp.plugins.xep_0490

.. autoclass:: XEP_0490
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0490.stanza
    :members:
    :undoc-members:

